==> huaweicloudsdkcss-3.1.133-py2.py3-none-any.whl: huaweicloudsdkcss/v1/model/create_clusters_tags_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateClustersTagsRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'cluster_id': 'str',
        'resource_type': 'str',
        'body': 'TagReq'
    }

    attribute_map = {
        'cluster_id': 'cluster_id',
        'resource_type': 'resource_type',
        'body': 'body'
    }

    def __init__(self, cluster_id=None, resource_type=None, body=None):
        """CreateClustersTagsRequest

        The model defined in huaweicloud sdk

        :param cluster_id: 指定待添加标签的集群ID。
        :type cluster_id: str
        :param resource_type: 资源类型，当前固定值为“css-cluster”，表示是集群类型。
        :type resource_type: str
        :param body: Body of the CreateClustersTagsRequest
        :type body: :class:`huaweicloudsdkcss.v1.TagReq`
        """
        
        

        self._cluster_id = None
        self._resource_type = None
        self._body = None
        self.discriminator = None

        self.cluster_id = cluster_id
        self.resource_type = resource_type
        if body is not None:
            self.body = body

    @property
    def cluster_id(self):
        """Gets the cluster_id of this CreateClustersTagsRequest.

        指定待添加标签的集群ID。

        :return: The cluster_id of this CreateClustersTagsRequest.
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        """Sets the cluster_id of this CreateClustersTagsRequest.

        指定待添加标签的集群ID。

        :param cluster_id: The cluster_id of this CreateClustersTagsRequest.
        :type cluster_id: str
        """
        self._cluster_id = cluster_id

    @property
    def resource_type(self):
        """Gets the resource_type of this CreateClustersTagsRequest.

        资源类型，当前固定值为“css-cluster”，表示是集群类型。

        :return: The resource_type of this CreateClustersTagsRequest.
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this CreateClustersTagsRequest.

        资源类型，当前固定值为“css-cluster”，表示是集群类型。

        :param resource_type: The resource_type of this CreateClustersTagsRequest.
        :type resource_type: str
        """
        self._resource_type = resource_type

    @property
    def body(self):
        """Gets the body of this CreateClustersTagsRequest.

        :return: The body of this CreateClustersTagsRequest.
        :rtype: :class:`huaweicloudsdkcss.v1.TagReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this CreateClustersTagsRequest.

        :param body: The body of this CreateClustersTagsRequest.
        :type body: :class:`huaweicloudsdkcss.v1.TagReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateClustersTagsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcss-3.1.152-py2.py3-none-any.whl: huaweicloudsdkcss/v1/model/create_clusters_tags_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateClustersTagsRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'cluster_id': 'str',
        'resource_type': 'str',
        'body': 'TagReq'
    }

    attribute_map = {
        'cluster_id': 'cluster_id',
        'resource_type': 'resource_type',
        'body': 'body'
    }

    def __init__(self, cluster_id=None, resource_type=None, body=None):
        r"""CreateClustersTagsRequest

        The model defined in huaweicloud sdk

        :param cluster_id: 指定待添加标签的集群ID。
        :type cluster_id: str
        :param resource_type: 资源类型，当前固定值为“css-cluster”，表示是集群类型。
        :type resource_type: str
        :param body: Body of the CreateClustersTagsRequest
        :type body: :class:`huaweicloudsdkcss.v1.TagReq`
        """
        
        

        self._cluster_id = None
        self._resource_type = None
        self._body = None
        self.discriminator = None

        self.cluster_id = cluster_id
        self.resource_type = resource_type
        if body is not None:
            self.body = body

    @property
    def cluster_id(self):
        r"""Gets the cluster_id of this CreateClustersTagsRequest.

        指定待添加标签的集群ID。

        :return: The cluster_id of this CreateClustersTagsRequest.
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        r"""Sets the cluster_id of this CreateClustersTagsRequest.

        指定待添加标签的集群ID。

        :param cluster_id: The cluster_id of this CreateClustersTagsRequest.
        :type cluster_id: str
        """
        self._cluster_id = cluster_id

    @property
    def resource_type(self):
        r"""Gets the resource_type of this CreateClustersTagsRequest.

        资源类型，当前固定值为“css-cluster”，表示是集群类型。

        :return: The resource_type of this CreateClustersTagsRequest.
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        r"""Sets the resource_type of this CreateClustersTagsRequest.

        资源类型，当前固定值为“css-cluster”，表示是集群类型。

        :param resource_type: The resource_type of this CreateClustersTagsRequest.
        :type resource_type: str
        """
        self._resource_type = resource_type

    @property
    def body(self):
        r"""Gets the body of this CreateClustersTagsRequest.

        :return: The body of this CreateClustersTagsRequest.
        :rtype: :class:`huaweicloudsdkcss.v1.TagReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this CreateClustersTagsRequest.

        :param body: The body of this CreateClustersTagsRequest.
        :type body: :class:`huaweicloudsdkcss.v1.TagReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateClustersTagsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
